@@ -35,7 +35,7 @@
 (require 'sb-text)
 (luna-define-class shimbun-asahi (shimbun-text) ())
 
-(defvar shimbun-asahi-url "http://spin.asahi.com/"
+(defvar shimbun-asahi-url "http://www.asahi.com/"
   "Name of the parent url.")
 
 (defvar shimbun-asahi-groups '("national" "business" "politics"
