@@ -62,7 +62,8 @@
 	  (if (stringp method)
 	      (intern method)
 	    method)
-	  (w3m-expand-url action baseurl)
+	  (and action
+	       (w3m-expand-url action baseurl))
 	  charlst
 	  nil))
 
@@ -251,10 +252,12 @@ return them with the flag."
 		(cons (w3m-form-new
 		       (or method "get")
 		       (or action
-			   (progn
-			     (string-match w3m-url-components-regexp w3m-current-url)
-			     (substring w3m-current-url 0
-					(or (match-beginning 6) (match-beginning 8)))))
+			   (and w3m-current-url
+				(string-match w3m-url-components-regexp
+					      w3m-current-url)
+				(substring w3m-current-url 0
+					   (or (match-beginning 6)
+					       (match-beginning 8)))))
 		       nil
 		       accept-charset)
 		      forms)))
@@ -302,7 +305,8 @@ return them with the flag."
 	      (let ((start (point))
 		    value)
 		(skip-chars-forward "^<")
-		(setq value (buffer-substring start (point)))
+		(setq value (w3m-decode-entities-string
+			     (buffer-substring start (point))))
 		(when name
 		  (w3m-form-put (car forms)
 				name
@@ -324,10 +328,12 @@ return them with the flag."
 		    (setq vbeg (point))
 		    (skip-chars-forward "^<")
 		    (setq svalue
-			  (mapconcat 'identity
-				     (split-string
-				      (buffer-substring vbeg (point)) "\n")
-				     ""))
+			  (w3m-decode-entities-string
+			   (mapconcat 'identity
+				      (split-string
+				       (buffer-substring vbeg (point))
+				       "[ \t\r\f\n]+")
+				      " ")))
 		    (unless value
 		      (setq value svalue))
 		    (when selected
@@ -350,11 +356,11 @@ return them with the flag."
 	(when (and fid
 		   (string-match
 		    "fid=\\([^/]+\\)/type=\\([^/]+\\)/name=\\(.*\\)$"
-		    fid))
-	  (setq form (nth (string-to-number (match-string 1 fid))
-			  forms)
-		type (match-string 2 fid)
-		name (match-string 3 fid))
+		    fid)
+		   (setq form (nth (string-to-number (match-string 1 fid))
+				   forms)
+			 type (match-string 2 fid)
+			 name (match-string 3 fid)))
 	  (cond
 	   ((or (string= type "submit")
 		(string= type "image"))
